/*
 * HTMLWriter.java
 *
 * comments here.
 *
 * @author   Michiaki Tatsubori
 * @version  %VERSION% %DATE%
 * @see      java.lang.Object
 *
 * COPYRIGHT 1998 by Michiaki Tatsubori, ALL RIGHTS RESERVED.
 */
package openjava.debug.gui;


import java.io.*;
import java.util.Enumeration;
import openjava.ptree.*;
import openjava.mop.Environment;


/**
 * The class <code>HTMLWriter</code> is a Visitor role
 * in the Visitor pattern and this also visits each child
 * <code>ParseTree</code> object from left to right.
 * <p>
 *
 * @author   Michiaki Tatsubori
 * @version  1.0
 * @since    %SOFTWARE% 1.0
 * @see openjava.ptree.ParseTree
 * @see openjava.ptree.util.ParseTreeVisitor
 */
public class HTMLWriter extends ParseTreeVisitor
{

    protected ParseTree highlight;

    private void writeHighLightBegin() {
	out.print( "<b>" );
    }

    private void writeHighLightEnd() {
	out.print( "</b>" );
    }

    public void writeHTMLBegin() {
	out.print( "<pre>" );
    }

    public void writeHTMLEnd() {
	out.print( "</pre>" );
    }
    
    /**
     * Allocates a source code writer.
     *
     */
    public HTMLWriter( PrintWriter out, ParseTree highlight ) {
	super( out );
	this.highlight = highlight;
    }

    public void visit( AllocationExpression p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( ArrayAccess p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( ArrayAllocationExpression p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( ArrayInitializer p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( AssignmentExpression p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( BinaryExpression p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( Block p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( BreakStatement p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( CaseGroup p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( CaseGroupList p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( CaseLabel p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( CaseLabelList p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( CastExpression p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( CatchBlock p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( CatchList p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( ClassDeclaration p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( ClassDeclarationList p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( ClassLiteral p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( CompilationUnit p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( ConditionalExpression p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( ConstructorDeclaration p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( ConstructorInvocation p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( ContinueStatement p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( DoWhileStatement p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( EmptyStatement p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( ExpressionList p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( ExpressionStatement p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( FieldAccess p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( FieldDeclaration p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( ForStatement p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( IfStatement p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( InstanceofExpression p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( LabeledStatement p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( Literal p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( MemberDeclarationList p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( MemberInitializer p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( MethodCall p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( MethodDeclaration p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( ModifierList p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( Parameter p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( ParameterList p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( ReturnStatement p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( SelfAccess p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( StatementList p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( SwitchStatement p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( SynchronizedStatement p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( ThrowStatement p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( TryStatement p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( TypeName p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( UnaryExpression p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( Variable p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( VariableDeclaration p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( VariableDeclarator p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

    public void visit( WhileStatement p )
	throws ParseTreeException
    {
	if (p == highlight)  writeHighLightBegin();
	super.visit( p );
	if (p == highlight)  writeHighLightEnd();
    }

}
